# Flyto2 Core - Source Available License
# Copyright (c) 2025 Flyto2. All Rights Reserved.
#
# This source code is licensed under the Flyto2 Source Available License v1.0.
# Commercial use requires a license. See LICENSE for details.

"""
Browser Composite Modules

High-level browser automation workflows combining multiple atomic modules.
"""
from .scrape_to_json import WebScrapeToJson

__all__ = [
    'WebScrapeToJson',
]
