# Flyto2 Core - Source Available License
# Copyright (c) 2025 Flyto2. All Rights Reserved.
#
# This source code is licensed under the Flyto2 Source Available License v1.0.
# Commercial use requires a license. See LICENSE for details.

"""
Notification Modules
Send and receive notifications via various platforms.
"""
from .send import notify_send

__all__ = ['notify_send']
